%define name    VirtualGL
%define version 2.6.5
%define release %mkrel 1
%define libpackage %mklibname %{name}
%define _libexecdir /usr/libexec

Name:           %{name}
Summary:        A toolkit for displaying OpenGL applications to thin clients
Version:        %{version}
Release:        %{release}
Source0:        https://sourceforge.net/projects/virtualgl/files/%{version}/%{name}-%{version}.tar.gz
URL:            http://www.virtualgl.org
Group:          Networking/Other
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot
License:        wxWindows Library License v3.1

Patch1:         %{name}-redhatpathsfix.patch
Patch2:         %{name}-redhatlibexecpathsfix.patch
Patch3:		    %{name}-link-libs.patch

Obsoletes: virtualgl
Provides: virtualgl = %{version}-%{release}

BuildRequires: cmake gcc-c++ glibc-devel jpeg-devel X11-devel jpeg-devel opencl-devel fltk-devel pkgconfig(glu)
%ifarch x86_64
Requires:	ia32-libs
%endif

%description
VirtualGL is a library which allows most Linux OpenGL applications to be
remotely displayed to a thin client without the need to alter the
applications in any way.  VGL inserts itself into an application at run time
and intercepts a handful of GLX calls, which it reroutes to the server's
display (which presumably has a 3D accelerator attached.)  This causes all
3D rendering to occur on the server's display.  As each frame is rendered
by the server, VirtualGL reads back the pixels from the server's framebuffer
and sends them to the client for re-compositing into the appropriate X
Window.  VirtualGL can be used to give hardware-accelerated 3D capabilities to
VNC or other remote display environments that lack GLX support.  In a LAN
environment, it can also be used with its built-in motion-JPEG video delivery
system to remotely display full-screen 3D applications at 20+ frames/second.

VirtualGL is based upon ideas presented in various academic papers on
this topic, including "A Generic Solution for Hardware-Accelerated Remote
Visualization" (Stegmaier, Magallon, Ertl 2002) and "A Framework for
Interactive Hardware Accelerated Remote 3D-Visualization" (Engel, Sommer,
Ertl 2000.)

%package devel
Summary: A toolkit for displaying OpenGL applications to thin clients
Group: Networking/Other
Requires: %{name} = %{version}

Obsoletes: virtualgl-devel
Provides:  virtualgl-devel = %{version}-%{release}

%description devel
VirtualGL is a library which allows most Linux OpenGL applications to be
remotely displayed to a thin client without the need to alter the
applications in any way.  VGL inserts itself into an application at run time
and intercepts a handful of GLX calls, which it reroutes to the server's
display (which presumably has a 3D accelerator attached.)  This causes all
3D rendering to occur on the server's display.  As each frame is rendered
by the server, VirtualGL reads back the pixels from the server's framebuffer
and sends them to the client for re-compositing into the appropriate X
Window.  VirtualGL can be used to give hardware-accelerated 3D capabilities to
VNC or other remote display environments that lack GLX support.  In a LAN
environment, it can also be used with its built-in motion-JPEG video delivery
system to remotely display full-screen 3D applications at 20+ frames/second.

VirtualGL is based upon ideas presented in various academic papers on
this topic, including "A Generic Solution for Hardware-Accelerated Remote
Visualization" (Stegmaier, Magallon, Ertl 2002) and "A Framework for
Interactive Hardware Accelerated Remote 3D-Visualization" (Engel, Sommer,
Ertl 2000.)

%prep
%setup -q
%patch1 -p1 -b .redhatpathfix
%patch2 -p1 -b .redhatlibexecpathsfix
%patch3 -p1 -b .libs

sed -i -e 's,"glx.h",<GL/glx.h>,' server/*.[hc]*
# Remove bundled libraries
rm -r server/fltk
rm doc/LICENSE-*.txt

%build
%cmake \
         -DVGL_SYSTEMFLTK=1 \
         -DVGL_SYSTEMGLX=1 \
         -DVGL_FAKEXCB=1 \
         -DVGL_USESSL=0 \
         -DVGL_BUILDSTATIC=0 \
         -DVGL_FAKEOPENCL=1 \
         -DVGL_BUILDSERVER=1 \
         -DVGL_USEXV=1 \
         -DTJPEG_INCLUDE_DIR=%{_includedir}/ \
         -DTJPEG_LIBRARY=%{_libdir}/libturbojpeg.so \
         -DCMAKE_INSTALL_PREFIX=%{_prefix}/ \
         -DCMAKE_INSTALL_LIBDIR=%{_libdir}/VirtualGL/ \
         -DCMAKE_INSTALL_DOCDIR=%{_docdir}/%{name}/ \
         -DCMAKE_INSTALL_BINDIR=%{_bindir}/ .

make %{?_smp_mflags}

%install
%cmake_install
# glxinfo conflicts with command from glx-utils so lets do what Arch does
# and rename the command
mv $RPM_BUILD_ROOT/%{_bindir}/glxinfo $RPM_BUILD_ROOT/%{_bindir}/vglxinfo
mkdir -p $RPM_BUILD_ROOT%{_libdir}/fakelib/
ln -sf %{_libdir}/VirtualGL/librrfaker.so $RPM_BUILD_ROOT%{_libdir}/fakelib/libGL.so
# fix for bz1088475
mkdir $RPM_BUILD_ROOT%{_libexecdir}
%if 0%{?__isa_bits} == 64
mv $RPM_BUILD_ROOT%{_bindir}/.vglrun.vars64 $RPM_BUILD_ROOT%{_libexecdir}/vglrun.vars64
%else
mv $RPM_BUILD_ROOT%{_bindir}/.vglrun.vars32 $RPM_BUILD_ROOT%{_libexecdir}/vglrun.vars32
%endif

%clean
rm -rf %{buildroot}

%post
ldconfig

%postun
ldconfig

%files
%{_docdir}/%{name}/
%{_bindir}/tcbench
%{_bindir}/nettest
%{_bindir}/cpustat
%{_bindir}/vglclient
%{_bindir}/vglconfig
%{_bindir}/vglconnect
%{_bindir}/vglgenkey
%{_bindir}/vgllogin
%{_bindir}/vglserver_config
%{_bindir}/vglrun
%{_bindir}/vglxinfo
%{_bindir}/glreadtest
%if 0%{?__isa_bits} == 64
%{_bindir}/glxspheres64
%{_libexecdir}/vglrun.vars64
%else
%{_bindir}/glxspheres
%{_libexecdir}/vglrun.vars32
%endif
%{_libdir}/VirtualGL/
%{_libdir}/fakelib/

%files devel
%{_includedir}/rrtransport.h
%{_includedir}/rr.h


%changelog
* Wed Nov 10 2021 yodelu 2.6.5-1pclos2021
- update

* Wed May 29 2013 Texstar <texstar at gmail.com> 2.3.2-1pclos2013
- import into pclos
